@@ -1,6 +1,6 @@
 /*@z01.c:Supervise:StartSym, AllowCrossDb, Encapsulated, etc.@****************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,7 +20,7 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z01.c                                                      */
 /*  MODULE:       Supervise                                                  */
@@ -28,7 +28,7 @@
 /*                PrintSym, AllowCrossDb, Encapsulated                       */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -86,13 +86,14 @@ BOOLEAN	AltErrorFormat;
 
 /*****************************************************************************/
 /*                                                                           */
-/*  BackEnd		POSTSCRIPT or PLAINTEXT                              */
+/*  BackEnd		POSTSCRIPT, PLAINTEXT or PDF                         */
 /*  BackEndWord         "PostScript" or "PlainText"                          */
 /*  PlainCharWidth      if PLAINTEXT, the width of each character            */
 /*  PlainCharHeight     if PLAINTEXT, the height of each character           */
 /*  PlainFormFeed       if PLAINTEXT, TRUE if separate components with \f.   */
 /*  InitializeAll       TRUE if this is an initializing run.                 */
 /*  MsgCat              category for locale-specific messages                */
+/*  TotalWordCount      total number of words printed                        */
 /*                                                                           */
 /*****************************************************************************/
 
@@ -104,6 +105,7 @@ BOOLEAN InitializeAll;
 #if LOCALE_ON
 nl_catd MsgCat;
 #endif
+int TotalWordCount;
 
 
 /*****************************************************************************/
@@ -137,7 +139,7 @@ BOOLEAN xleft, BOOLEAN xright, BOOLEAN xindef, unsigned char xprec)
 /*  Print usage information on file fp.                                      */
 /*                                                                           */
 /*****************************************************************************/
-#define lput(s) fprintf(fp, "%s\n", s)
+#define lput(str) fprintf(fp, "%s\n", str)
 
 static void PrintUsage(FILE *fp)
 {
@@ -146,6 +148,7 @@ static void PrintUsage(FILE *fp)
   lput(""								    );
   lput("  -s              suppress access to cross reference database"	    );
   lput("  -EPS            EPS (Encapsulated PostScript) output"		    );
+  lput("  -Z              PDF (Adobe Portable Document Format) output"      );
   lput("  -p              plain text output instead of PostScript"	    );
   lput("  -P              like -p but with form-feed char between pages"    );
   lput("  -S              safe execution (disable calls to system(3))"	    );
@@ -153,6 +156,7 @@ static void PrintUsage(FILE *fp)
   lput("  -o file         output to file instead of stdout"		    );
   lput("  -e file         error messages to file instead of stderr"	    );
   lput("  -a              alternative error format:  file:line:col ..."	    );
+  lput("  -w              print total number of words in output"	    );
   lput("  -i file         like @SysInclude { file }; not recommended"	    );
   lput("  -I directory    add directory to include file search path"	    );
   lput("  -C directory    add directory to LCM file search path"	    );
@@ -160,6 +164,7 @@ static void PrintUsage(FILE *fp)
   lput("  -H directory    add directory to hyphenation file search path"    );
   lput("  -D directory    add directory to database file search path"	    );
   lput("  --option{value} set option e.g. --'@InitialFont{Times Base 10p}'" );
+  lput("  -c file         use file.li instead of lout.li for crossrefs"	    );
   lput("  -x              initializing run, not for ordinary use"	    );
   lput("  -u              print this usage message on stderr and exit"	    );
   lput("  -V              print version and configuration information"	    );
@@ -209,6 +214,7 @@ int main(int argc, char *argv[])
   long MemCheckLong;
   FULL_CHAR oname[MAX_BUFF], oval[MAX_BUFF], buff[MAX_BUFF], *p;
   int bp;  OBJECT z;
+  BOOLEAN seen_wordcount;
 #if LOCALE_ON
   char catname[MAX_BUFF], *loc;
 #endif
@@ -230,7 +236,14 @@ int main(int argc, char *argv[])
   MsgCat = catopen(catname, 0);
 #endif
 
+#if COLLATE
+  if (!setlocale (LC_COLLATE, ""))
+    Error(1, 30, "unable to initialize collation", WARN, no_fpos);
+#endif /* COLLATE */
+
   /* initialise various modules, add current directory to search paths */
+  TotalWordCount = 0;
+  seen_wordcount = FALSE;
   BackEnd = POSTSCRIPT;
   BackEndWord = STR_POSTSCRIPT;
   PlainCharWidth = PLAIN_WIDTH;
@@ -397,7 +410,7 @@ int main(int argc, char *argv[])
 	fprintf(stderr, "%-28s %s\n",
 	  "Basser Lout written by:", "Jeffrey H. Kingston (jeff@cs.usyd.edu.au)");
 	fprintf(stderr, "%-28s %s\n",
-	  "Free source available from:", "ftp://ftp.cs.su.oz.au/jeff/lout");
+	  "Free source available from:", "ftp://ftp.cs.usyd.edu.au/jeff/lout");
 	fprintf(stderr, "%-28s %s %s\n",
 	  "This executable compiled:", __TIME__, __DATE__);
 	fprintf(stderr, "%-28s %s%s%s\n", "System include directory:",
@@ -408,10 +421,31 @@ int main(int argc, char *argv[])
 	  USE_STAT ? " yes" : " no");
 	fprintf(stderr, "Safe execution (disabling system()) is default:%s\n",
 	  SAFE_DFT ? " yes" : " no");
+	fprintf(stderr, "strcoll() used for sorting collation sequence:%s\n",
+	  COLLATE ? " yes" : " no");
+	fprintf(stderr, "\n");
+	fprintf(stderr, "Basser Lout comes with ABSOLUTELY NO WARRANTY.\n");
+	fprintf(stderr, "This is free software, and you are welcome to\n");
+	fprintf(stderr, "redistribute it under certain conditions.  For\n");
+	fprintf(stderr, "details on both points, consult the GNU General\n");
+	fprintf(stderr, "Public License (distributed with this software).\n");
 	exit(0);
 	break;
 
 
+      case CH_FLAG_WORDS:
+     
+	seen_wordcount = TRUE;
+	break;
+
+
+      case CH_FLAG_PDF:
+
+	BackEnd = PDF;
+	BackEndWord = STR_PDF;
+	break;
+
+
       case CH_FLAG_FFPLAIN:
 
 	PlainFormFeed = TRUE;
@@ -652,6 +686,8 @@ int main(int argc, char *argv[])
   load(KW_COLOR,       COLOUR,         TRUE,   TRUE,   FALSE, DEFAULT_PREC);
   load(KW_LANGUAGE,    LANGUAGE,       TRUE,   TRUE,   FALSE, DEFAULT_PREC);
   load(KW_CURR_LANG,   CURR_LANG,      FALSE,  FALSE,  FALSE, DEFAULT_PREC);
+  load(KW_CURR_FAMILY, CURR_FAMILY,    FALSE,  FALSE,  FALSE, DEFAULT_PREC);
+  load(KW_CURR_FACE,   CURR_FACE,      FALSE,  FALSE,  FALSE, DEFAULT_PREC);
   load(KW_COMMON,      COMMON,         TRUE,   TRUE,   FALSE, DEFAULT_PREC);
   load(KW_RUMP,        RUMP,           TRUE,   TRUE,   FALSE, DEFAULT_PREC);
   load(KW_INSERT,      INSERT,         TRUE,   TRUE,   FALSE, DEFAULT_PREC);
@@ -733,6 +769,10 @@ int main(int argc, char *argv[])
   /* remove any leftover filter temporary files */
   FilterScavenge(TRUE);
 
+  /* print word count, if required */
+  if( seen_wordcount )
+    Error(1, 29, "total of all words printed: %d", WARN,no_fpos,TotalWordCount);
+
   /* check for unbalanced error blocks */
   CheckErrorBlocks();
 
