@@ -1,6 +1,6 @@
 /*@z05.c:Read Definitions:ReadFontDef()@**************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z05.c                                                      */
 /*  MODULE:       Read Definitions                                           */
 /*  EXTERNS:      ReadPrependDef(), ReadDatabaseDef(), ReadDefinitions()     */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -275,6 +275,8 @@ static void ReadTokenList(OBJECT token, OBJECT res)
     case COLOUR:
     case LANGUAGE:
     case CURR_LANG:
+    case CURR_FAMILY:
+    case CURR_FACE:
     case COMMON:
     case RUMP:
     case INSERT:
