@@ -1,6 +1,6 @@
 /*@z06.c:Parser:PushObj(), PushToken(), etc.@*********************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z06.c                                                      */
 /*  MODULE:       Parser                                                     */
 /*  EXTERNS:      InitParser(), Parse()                                      */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 #define	LEFT_ASSOC	0
 #define	RIGHT_ASSOC	1
 
@@ -428,6 +428,8 @@ static BOOLEAN Reduce(void)
     case COLOUR:
     case LANGUAGE:
     case CURR_LANG:
+    case CURR_FAMILY:
+    case CURR_FACE:
     case COMMON:
     case RUMP:
     case INSERT:
@@ -967,6 +969,8 @@ BOOLEAN defs_allowed, BOOLEAN transfer_allowed)
       case COLOUR:
       case LANGUAGE:
       case CURR_LANG:
+      case CURR_FAMILY:
+      case CURR_FACE:
       case COMMON:
       case RUMP:
       case INSERT:
@@ -1038,15 +1042,6 @@ BOOLEAN defs_allowed, BOOLEAN transfer_allowed)
 	}
 	else x = nilobj;
 	Shift(t, precedence(t), 0, TRUE, FALSE);
-	/* *** now doing this inside Shift() ***
-	if( ttop == initial_ttop )
-	{
-	  *token = x;
-	  debugcond0(DOP, DD, debug_now, "] end Parse(); final stacks are:");
-	  ifdebugcond(DOP, DD, debug_now, DebugStacks(initial_ttop, obj_prev));
-	  return PopObj();
-	}
-	*** */
 	t = (x != nilobj) ? x : LexGetToken();
 	break;
 
@@ -1054,15 +1049,6 @@ BOOLEAN defs_allowed, BOOLEAN transfer_allowed)
       case RBR:
       
 	Shift(t, precedence(t), 0, TRUE, FALSE);
-	/* *** now doing this inside Shift() ***
-	if( ttop == initial_ttop )
-	{
-	  *token = nilobj;
-	  debugcond0(DOP, DD, debug_now, "] end Parse(); final stacks are:");
-	  ifdebugcond(DOP, DD, debug_now, DebugStacks(initial_ttop, obj_prev));
-	  return PopObj();
-	}
-	*** */
 	t = LexGetToken();
 	break;
 				
