@@ -1,6 +1,6 @@
 /*@z13.c:Object Breaking:BreakJoinedGroup()@**********************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z13.c                                                      */
 /*  MODULE:       Object Breaking                                            */
 /*  EXTERNS:      BreakObject()                                              */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 #define	broken(x)	back(x, ROWM)	/* OK since no vertical sizes yet    */
 
 
@@ -51,16 +51,16 @@ CONSTRAINT *c, FULL_LENGTH *res_back, FULL_LENGTH *res_fwd)
   { m = BreakObject(m, &yc);
     b = back(m, COLM);
     f = fwd(m, COLM);
-    SetConstraint(yc, min(bc(yc), bfc(yc)-f), bfc(yc), min(fc(yc), bfc(yc)-b));
+    SetConstraint(yc, find_min(bc(yc), bfc(yc)-f), bfc(yc), find_min(fc(yc), bfc(yc)-b));
   }
   else b = f = 0;
   for( link = start;  link != NextDown(stop);  link = NextDown(link) )
   { Child(y, link);
     if( !is_definite(type(y)) || y == m )  continue;
     y = BreakObject(y, &yc);
-    b = max(b, back(y, COLM));
-    f = max(f, fwd(y, COLM));
-    SetConstraint(yc, min(bc(yc), bfc(yc)-f), bfc(yc), min(fc(yc), bfc(yc)-b));
+    b = find_max(b, back(y, COLM));
+    f = find_max(f, fwd(y, COLM));
+    SetConstraint(yc, find_min(bc(yc), bfc(yc)-f), bfc(yc), find_min(fc(yc), bfc(yc)-b));
   }
   if( !FitsConstraint(b, f, *c) )
   { debug3(DOB, D, "  in BreakJoinedGroup: !FitsConstraint(%s, %s, %s)",
@@ -88,7 +88,7 @@ static OBJECT BreakVcat(OBJECT x, CONSTRAINT *c)
   BOOLEAN dble_found;
   debug1(DOB, DD, "[ BreakVcat(x, %s)", EchoConstraint(c));
   assert(Down(x) != x, "BreakVcat: Down(x) == x!" );
-  SetConstraint(tc, MAX_FULL_LENGTH, min(bfc(*c), fc(*c)), MAX_FULL_LENGTH);
+  SetConstraint(tc, MAX_FULL_LENGTH, find_min(bfc(*c), fc(*c)), MAX_FULL_LENGTH);
   
   dble_found = FALSE;  dble_fwd = 0;  start_group = nilobj;
   for( link = Down(x);  link != x;  link = NextDown(link) )
@@ -102,7 +102,7 @@ static OBJECT BreakVcat(OBJECT x, CONSTRAINT *c)
 	if( !FitsConstraint(b, f, tc) )
 	  BreakJoinedGroup(start_group, link, m, &tc, &b, &f);
 	dble_found = TRUE;
-	dble_fwd = max(dble_fwd, b + f);
+	dble_fwd = find_max(dble_fwd, b + f);
 	start_group = nilobj;
 	debug1(DOB, DD, "  end group, dble_fwd: %s", EchoLength(dble_fwd));
       }
@@ -119,7 +119,7 @@ static OBJECT BreakVcat(OBJECT x, CONSTRAINT *c)
     else
     {
       /* continue with current group */
-      b = max(b, back(y, COLM));  f = max(f, fwd(y, COLM));
+      b = find_max(b, back(y, COLM));  f = find_max(f, fwd(y, COLM));
       if( fwd(y, COLM) > fwd(m, COLM) )  m = y;
       debug3(DOB, DD, "  in group%s (b = %s, f = %s):",
 	m == y ? " (new max)" : "",
@@ -134,9 +134,9 @@ static OBJECT BreakVcat(OBJECT x, CONSTRAINT *c)
     /* finish off and break this last group, and set sizes of x */
     if( !FitsConstraint(b, f, tc) )
       BreakJoinedGroup(start_group, LastDown(x), m, &tc, &b, &f);
-    dble_fwd = max(dble_fwd, b + f);
+    dble_fwd = find_max(dble_fwd, b + f);
     debug1(DOB, DD, "  ending last group, dble_fwd: %s",EchoLength(dble_fwd));
-    back(x, COLM) = 0;  fwd(x, COLM) = min(MAX_FULL_LENGTH, dble_fwd);
+    back(x, COLM) = 0;  fwd(x, COLM) = find_min(MAX_FULL_LENGTH, dble_fwd);
   }
   else
   {
@@ -303,40 +303,40 @@ static OBJECT BreakTable(OBJECT x, CONSTRAINT *c)
 
       case BACK:
       
-	back_max = min(bc(*c), bwidth + av_colsize * bcount);
+	back_max = find_min(bc(*c), bwidth + av_colsize * bcount);
 	col_size = (back_max - bwidth) / bcount;
 	if( col_size > prev_col_size && col_size - prev_col_size < PT )
 	  col_size = prev_col_size;
 	SetConstraint(mc,
-	  min(MAX_FULL_LENGTH, col_size + pd_extra),
-	  min(MAX_FULL_LENGTH, col_size + pd_extra + sd_extra),
-	  min(MAX_FULL_LENGTH, col_size + sd_extra));
+	  find_min(MAX_FULL_LENGTH, col_size + pd_extra),
+	  find_min(MAX_FULL_LENGTH, col_size + pd_extra + sd_extra),
+	  find_min(MAX_FULL_LENGTH, col_size + sd_extra));
 	break;
 
 
       case ON:
       
-	fwd_max = min(fc(*c), fwidth + av_colsize * fcount);
+	fwd_max = find_min(fc(*c), fwidth + av_colsize * fcount);
 	col_size = (fwd_max - fwidth) / fcount;
 	if( col_size > prev_col_size && col_size - prev_col_size < PT )
 	  col_size = prev_col_size;
 	SetConstraint(mc,
-	  min(MAX_FULL_LENGTH, pd_extra + back(my, COLM)),
-	  min(MAX_FULL_LENGTH, pd_extra + back(my, COLM) + col_size + sd_extra),
-	  min(MAX_FULL_LENGTH, col_size + sd_extra));
+	  find_min(MAX_FULL_LENGTH, pd_extra + back(my, COLM)),
+	  find_min(MAX_FULL_LENGTH, pd_extra + back(my, COLM) + col_size + sd_extra),
+	  find_min(MAX_FULL_LENGTH, col_size + sd_extra));
 	break;
 
 
       case FWD:
       
-	fwd_max = min(fc(*c), fwidth + av_colsize * fcount);
+	fwd_max = find_min(fc(*c), fwidth + av_colsize * fcount);
 	col_size = (fwd_max - fwidth) / fcount;
 	if( col_size > prev_col_size && col_size - prev_col_size < PT )
 	  col_size = prev_col_size;
 	SetConstraint(mc,
-	  min(MAX_FULL_LENGTH, col_size + pd_extra),
-	  min(MAX_FULL_LENGTH, col_size + pd_extra + sd_extra),
-	  min(MAX_FULL_LENGTH, col_size + sd_extra));
+	  find_min(MAX_FULL_LENGTH, col_size + pd_extra),
+	  find_min(MAX_FULL_LENGTH, col_size + pd_extra + sd_extra),
+	  find_min(MAX_FULL_LENGTH, col_size + sd_extra));
 	break;
 
 
@@ -410,18 +410,33 @@ OBJECT BreakObject(OBJECT x, CONSTRAINT *c)
   debug3(DOB, DD,  "[ BreakObject(x (%s,%s),  %s), x =",
 	EchoLength(back(x, COLM)), EchoLength(fwd(x, COLM)), EchoConstraint(c));
   ifdebug(DOB, DD, DebugObject(x));
-  assert( bc(*c)>=0 && bfc(*c)>=0 && fc(*c)>=0, "BreakObject: neg constraint");
 
+  /* if constraint is negative (should really be never), replace with empty */
+  if( !(bc(*c)>=0 && bfc(*c)>=0 && fc(*c)>=0) )
+  {
+    Error(13, 11, "replacing with empty object: negative size constraint %s,%s,%s",
+      WARN, &fpos(x), EchoLength(bc(*c)), EchoLength(bfc(*c)), EchoLength(fc(*c)));
+    y = MakeWord(WORD, STR_EMPTY, &fpos(x));
+    back(y, COLM) = fwd(y, COLM) = 0;
+    ReplaceNode(y, x);
+    DisposeObject(x);
+    x = y;
+    debug0(DOB, DD, "] BreakObject returning (negative constraint).");
+    return x;
+  }
+
+  /* if no breaking required, return immediately */
   if( FitsConstraint(back(x, COLM), fwd(x, COLM), *c) )
   { debug0(DOB, DD, "] BreakObject returning (fits).");
     return x;
   }
+
   switch( type(x) )
   {
 
     case ROTATE:
     
-      if( BackEnd == POSTSCRIPT && InsertScale(x, c) )
+      if( BackEnd != PLAINTEXT && InsertScale(x, c) )
       {
 	Parent(x, Up(x));
 	Error(13, 3, "%s object scaled horizontally by factor %.2f (too wide)",
@@ -495,7 +510,7 @@ OBJECT BreakObject(OBJECT x, CONSTRAINT *c)
 	  EchoStyle(&save_style(x)), Image(type(x)), EchoObject(x));
 	x = BreakObject(x, c);
       }
-      else if( BackEnd == POSTSCRIPT && InsertScale(x, c) )
+      else if( BackEnd != PLAINTEXT && InsertScale(x, c) )
       { OBJECT tmp;
 	tmp = x;
 	Parent(x, Up(x));
@@ -527,7 +542,7 @@ OBJECT BreakObject(OBJECT x, CONSTRAINT *c)
     case INCGRAPHIC:
     case SINCGRAPHIC:
 
-      if( BackEnd == POSTSCRIPT && InsertScale(x, c) )
+      if( BackEnd != PLAINTEXT && InsertScale(x, c) )
       {
 	Parent(x, Up(x));
 	Error(13, 7, "%s scaled horizontally by factor %.2f (too wide)",
@@ -571,11 +586,11 @@ OBJECT BreakObject(OBJECT x, CONSTRAINT *c)
       Child(y, Down(x));
       f = FindShift(x, y, COLM);
       SetConstraint(yc,
-	min(bc(*c), bfc(*c)) - f, bfc(*c), min(fc(*c), bfc(*c)) + f);
+	find_min(bc(*c), bfc(*c)) - f, bfc(*c), find_min(fc(*c), bfc(*c)) + f);
       BreakObject(y, &yc);
       f = FindShift(x, y, COLM);
-      back(x, COLM) = min(MAX_FULL_LENGTH, max(0, back(y, COLM) + f));
-      fwd(x, COLM)  = min(MAX_FULL_LENGTH, max(0, fwd(y, COLM)  - f));
+      back(x, COLM) = find_min(MAX_FULL_LENGTH, find_max(0, back(y, COLM) + f));
+      fwd(x, COLM)  = find_min(MAX_FULL_LENGTH, find_max(0, fwd(y, COLM)  - f));
       break;
 
 
@@ -603,7 +618,7 @@ OBJECT BreakObject(OBJECT x, CONSTRAINT *c)
       { int sz;  OBJECT rpos;
 	/* shift the column mark of x to the left edge */
 	sz = size(x, COLM);
-	fwd(x, COLM) = min(MAX_FULL_LENGTH, sz);
+	fwd(x, COLM) = find_min(MAX_FULL_LENGTH, sz);
 	back(x, COLM) = 0;
 	rpos = x;
 	for( link = Down(x);  link != x;  link = NextDown(link) )
