@@ -1,6 +1,6 @@
 /*@z14.c:Fill Service:Declarations@*******************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z14.c                                                      */
 /*  MODULE:       Fill Service                                               */
 /*  EXTERNS:      FillObject()                                               */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 #define TOO_TIGHT_BAD	1048576	/* 2^20; badness of a too tight line         */
 #define TOO_LOOSE_BAD	65536	/* 2^16; the max badness of a too loose line */
 #define	TIGHT_BAD	4096	/* 2^12; the max badness of a tight line     */
@@ -38,6 +38,7 @@
 #define SQRT_TOO_LOOSE	512	/* 2^ 9; sqrt(TOO_LOOSE_BAD) (used to be)    */
 #define	SQRT_TIGHT_BAD	128	/* 2^ 7; sqrt(TIGHT_BAD) (used to be)        */
 #define	SQRT_LOOSE_BAD	128	/* 2^ 7; sqrt(LOOSE_BAD) (used to be)        */
+#define	SQRT_TOO_TIGHT	4096	/* 2^12; sqrt(TOO_TIGHT_BAD) (used to be)    */
 #define MAX_EXPAND	1
 #define MAX_SHRINK	3
 
@@ -79,8 +80,8 @@ typedef struct {
 /*                                                                           */
 /*  SetIntervalBadness(I)                                                    */
 /*                                                                           */
-/*  Private, calculates the badness and badness class of an interval.        */
-/*  Does not take into account any unbreakable gap at either end.            */
+/*  Private, calculates the badness and badness class of a non-empty         */
+/*  interval.  Does not take into account any unbreakable gap at either end. */
 /*                                                                           */
 /*****************************************************************************/
 
@@ -131,60 +132,159 @@ typedef struct {
     badness = (SQRT_LOOSE_BAD*(col_width - I.nat_width)) / col_width;	\
     I.badness += badness * badness;					\
   }									\
-  else if( BackEnd == POSTSCRIPT && allow_shrink &&			\
+  else if( BackEnd != PLAINTEXT && allow_shrink &&			\
     MAX_SHRINK*(I.nat_width-col_width) <= I.space_width )		\
   { I.class = TIGHT;							\
     badness = (SQRT_TIGHT_BAD*(col_width - I.nat_width)) / col_width;	\
     I.badness += badness * badness;					\
   }									\
-  else { I.class = TOO_TIGHT;  I.badness += TOO_TIGHT_BAD; }		\
+  else									\
+  { I.class = TOO_TIGHT;						\
+    badness = (SQRT_TOO_TIGHT*(col_width - I.nat_width)) / col_width;	\
+    I.badness += badness * badness;					\
+  }									\
 } /* end macro SetIntervalBadness */
 
 
 /*@::CorrectOversize()@*******************************************************/
 /*                                                                           */
-/*  CorrectOversize(x, link, y, etc_width, hyph_allowed)                     */
+/*  CorrectOversize(x, problem_link, etc_width)                              */
 /*                                                                           */
-/*  Child y of x, whose link is link, has caused an oversize error, either   */
-/*  because it is wider than etc_width, or because it is joined by unbreak-  */
-/*  able gaps on the left to other objects with oversize total size.         */
+/*  The child of x whose link is problem_link has caused an oversize error,  */
+/*  either because it is wider than etc_width, or because it is joined by    */
+/*  unbreakable gaps to other objects with oversize total size.              */
+/*                                                                           */
+/*  CorrectOversize first finds the subsequence of all objects connected     */
+/*  to the problem one by unbreakable gaps.  It then places all of these     */
+/*  objects into a single sub-object, and either scales it to fit or else    */
+/*  replaces it by an empty object.                                          */
 /*                                                                           */
 /*****************************************************************************/
+#define BEFORE_STATE	0
+#define EQUAL_STATE	1
+#define AFTER_STATE	2
 
-static void CorrectOversize(OBJECT x, OBJECT link, OBJECT y, int etc_width,
-  BOOLEAN hyph_allowed)
-{ OBJECT tmp, z, last_z, zlink, new_y, new_acat;
-  CONSTRAINT c;  FULL_LENGTH total_size;
+static void CorrectOversize(OBJECT x, OBJECT problem_link, int etc_width)
+{ OBJECT y, link, g, prev_link, problem, tmp, first_link, last_link;
+  CONSTRAINT c;  BOOLEAN jn;  int state;
   SetConstraint(c, etc_width, etc_width, etc_width);
+  debug2(DOF, DD, "CorrectOversize(%s, problem_link, %s)",
+    EchoObject(x), EchoLength(etc_width));
 
-  /* determine the range of objects involved:  NextDown(zlink) ... link */
-  last_z = nilobj;
-  total_size = size(y, COLM);
-  for( zlink = PrevDown(link);  zlink != x;  zlink = PrevDown(zlink) )
-  { Child(z, zlink);
-    if( type(z) != GAP_OBJ )
-    { total_size += size(z, COLM);
-      last_z = z;
-    }
-    else if( !nobreak(gap(z)) )
-      break;
-  }
-  assert( !FitsConstraint(0, total_size, c), "CorrectOversize: fits!" );
+  /* determine the range of objects involved:  first_link ... last_link */
+  first_link = last_link = nilobj;
 
-  /* make y be a single object containing all the culprits, if not already */
-  if( NextDown(zlink) != link )
+  /* move to the first definite component of the paragraph */
+  FirstDefinite(x, link, y, jn);
+  assert( link != x, "CorrectOversize: link == x!" );
+  state = (link == problem_link ? EQUAL_STATE : BEFORE_STATE);
+  prev_link = nilobj;
+
+  while( link != x )
   {
+    ifdebug(DOF, DD,
+	Child(tmp, link);
+	debug4(DOF, DD, "  examining %s %s (%s,%s)", Image(type(tmp)),
+	  EchoObject(tmp), EchoLength(back(tmp, COLM)),
+	  EchoLength(fwd(tmp, COLM)));
+    )
+
+    /* update first_link and last_link depending on where we are */
+    switch( state )
+    {
+
+      case BEFORE_STATE:
+
+	if( prev_link == nilobj || !nobreak(gap(g)) )
+	{
+	  debug0(DOF, DD, "  (before) setting or resetting first_link");
+	  first_link = link;
+	}
+	break;
+
+
+      case EQUAL_STATE:
+
+	if( first_link == nilobj )
+	{
+	  debug0(DOF, DD, "  (equal) setting or resetting first_link");
+	  first_link = link;
+	}
+	break;
+
+
+      case AFTER_STATE:
+
+	assert( g != nilobj && type(g) == GAP_OBJ, "CorrectOversize: g!" );
+	debug2(DOF, DD, "  (after) g = %s (nobreak = %s)",
+	  EchoGap(&gap(g)), bool(nobreak(gap(g))));
+	if( last_link == nilobj && !nobreak(gap(g)) )
+	{
+	  debug0(DOF, DD, "  (after) setting last_link to prev_link");
+	  last_link = prev_link;
+	}
+	break;
+
+    }
+    
+    /* move to next definite component of the paragraph */
+    prev_link = link;
+    NextDefiniteWithGap(x, link, y, g, jn);
+    if( state == EQUAL_STATE )
+      state = AFTER_STATE;
+    else if( link == problem_link )
+      state = EQUAL_STATE;
+  }
+  if( last_link == nilobj )
+  {
+    debug0(DOF, DD, "  (wrapup) setting last_link");
+    last_link = prev_link;
+  }
+  assert( first_link != nilobj, "CorrectOversize: first_link!" );
+
+
+  /* replace first_link to last_link by a single object, if not already */
+  if( first_link != last_link )
+  { FULL_LENGTH b, f;  OBJECT after, new_acat, new_y, prev;
+
+    /* re-calculate the size of sub-paragraph first_link to last_link */
+    link = first_link;
+    Child(y, link);
+    debug3(DOF, DD, "  first culprit %s,%s: %s", EchoLength(back(y, COLM)),
+      EchoLength(fwd(y, COLM)), EchoObject(y));
+    b = back(y, COLM);
+    f = 0;
+    do
+    {
+      prev = y;
+      NextDefiniteWithGap(x, link, y, g, jn);
+
+      assert( link != x, "CorrectOversize: link!" );
+      Child(y, link);
+      debug4(DOF, DD, "  culprit (%s) %s,%s: %s", EchoGap(&gap(g)),
+	EchoLength(back(y, COLM)), EchoLength(fwd(y, COLM)), EchoObject(y));
+      f += MinGap(fwd(prev, COLM), back(y, COLM), fwd(y, COLM), &gap(g));
+      if( mark(gap(g)) )  b += f, f = 0;
+
+    } while( link != last_link );
+    f += fwd(y, COLM);
+    b = find_min(MAX_FULL_LENGTH, b);
+    f = find_min(MAX_FULL_LENGTH, f);
+    debug2(DOF, DD, "culprits' width is %s,%s", EchoLength(b), EchoLength(f));
+
     /* create a new ACAT and put the culprits under it */
     New(new_acat, ACAT);
-    FposCopy(fpos(new_acat), fpos(last_z));
+    Child(tmp, Down(first_link));
+    FposCopy(fpos(new_acat), fpos(tmp));
     StyleCopy(save_style(new_acat), save_style(x));
-    back(new_acat, COLM) = 0;
-    fwd(new_acat, COLM) = total_size;
+    back(new_acat, COLM) = b;
+    fwd(new_acat, COLM) = f;
     back(new_acat, ROWM) = 0;
     fwd(new_acat, ROWM) = 0;
-    TransferLinks(NextDown(zlink), NextDown(link), new_acat);
+    after = NextDown(last_link);
+    TransferLinks(first_link, after, new_acat);
 
-    /* create a new ONE_COL, link the new ACAT to it, and insert it */
+    /* create a new ONE_COL and link the new ACAT to it */
     New(new_y, ONE_COL);
     FposCopy(fpos(new_y), fpos(new_acat));
     back(new_y, COLM) = back(new_acat, COLM);
@@ -192,46 +292,66 @@ static void CorrectOversize(OBJECT x, OBJECT link, OBJECT y, int etc_width,
     back(new_y, ROWM) = back(new_acat, ROWM);
     fwd(new_y, ROWM) = fwd(new_acat, ROWM);
     Link(new_y, new_acat);
-    Link(NextDown(zlink), new_y);
-    debug1(DOF, DD, "new_y = %s", EchoObject(new_y));
-    y = new_y;
+
+    /* insert the new ONE_COL in place and call it problem */
+    Link(after, new_y);
+    problem = new_y;
+    debug1(DOF, DD, "problem = %s", EchoObject(problem));
   }
 
-  if( BackEnd == POSTSCRIPT && InsertScale(y, &c) )
-  { OBJECT prnt;
-    Parent(prnt, Up(y));
+  /* else the culprit is the common child of first_link and last_link */
+  else
+  { Child(problem, first_link);
+    debug3(DOF, DD, "sole problem %s,%s is %s", EchoLength(back(problem, COLM)),
+      EchoLength(fwd(problem, COLM)), EchoObject(problem));
+  }
 
-    /* the problem has just been fixed, by inserting a @Scale above y */
-    if( is_word(type(y)) )
+  /* now problem should not fit the size constraint we have, but sometimes does */
+  if( FitsConstraint(back(problem, COLM), fwd(problem, COLM), c) )
+  {
+    /* problem went away, so print warning message */
+    Error(14, 8, "phantom oversized object", WARN, &fpos(problem));
+  }
+
+  else if( BackEnd != PLAINTEXT && InsertScale(problem, &c) )
+  { OBJECT prnt;
+    Parent(prnt, Up(problem));
+
+    /* the problem has just been fixed, by inserting a @Scale above problem */
+    if( is_word(type(problem)) )
     { Error(14, 1, "word %s horizontally scaled by factor %.2f (too wide for %s paragraph)",
-        WARN, &fpos(y), string(y), (float) bc(constraint(prnt)) / SF,
+        WARN, &fpos(problem), string(problem), (float) bc(constraint(prnt)) / SF,
 	EchoLength(etc_width));
     }
     else
-    { Error(14, 2, "%s object horizontally scaled by factor %.2f (too wide for %s paragraph)",
-        WARN, &fpos(y), EchoLength(size(y, COLM)),
+    {
+      Error(14, 2, "%s object horizontally scaled by factor %.2f (too wide for %s paragraph)",
+        WARN, &fpos(problem), EchoLength(size(problem, COLM)),
 	(float) bc(constraint(prnt)) / SF, EchoLength(etc_width));
     }
   }
+
   else
   {
-    /* fix the problem by replacing y by an empty object */
-    if( size(y, COLM) <= 0 )
-      Error(14, 3, "oversize object has size 0 or less", INTERN, &fpos(y));
-    if( is_word(type(y)) )
+    /* fix the problem by replacing problem by an empty object */
+    if( size(problem, COLM) <= 0 )
+      Error(14, 3, "oversize object has size 0 or less", INTERN, &fpos(problem));
+    if( is_word(type(problem)) )
     { Error(14, 4, "word %s deleted (too wide for %s paragraph)",
-	WARN, &fpos(y), string(y), EchoLength(etc_width));
+	WARN, &fpos(problem), string(problem), EchoLength(etc_width));
     }
     else
     { Error(14, 5, "%s object deleted (too wide for %s paragraph)",
-	WARN, &fpos(y), EchoLength(size(y, COLM)), EchoLength(etc_width));
+	WARN, &fpos(problem), EchoLength(size(problem, COLM)),
+	EchoLength(etc_width));
     }
     tmp = MakeWord(WORD, STR_EMPTY, &fpos(x));
     back(tmp, COLM) = fwd(tmp, COLM) = back(tmp, ROWM) = fwd(tmp, ROWM) = 0;
     word_font(tmp) = word_colour(tmp) = 0;
     word_language(tmp) = word_hyph(tmp) = 0;
-    Link(link, tmp);  DisposeChild(link);
+    Link(Up(problem), tmp);  DisposeChild(Up(problem));
   }
+  debug0(DOF, DD, "CorrectOversize returning");
 } /* end CorrectOversize */
 
 
@@ -449,7 +569,10 @@ static void CorrectOversize(OBJECT x, OBJECT link, OBJECT y, int etc_width,
     /* else no changes since tabs hide them */				\
   }									\
   I.llink = Up(lgap);							\
-  if( I.llink == I.rlink )  I.class = EMPTY_INTERVAL;			\
+  if( I.llink == I.rlink )						\
+  { I.class = EMPTY_INTERVAL;						\
+    I.badness = TOO_TIGHT_BAD + 1;					\
+  }									\
   else									\
   {									\
     if( save_cwid(lgap) != nilobj )					\
@@ -579,8 +702,8 @@ static FULL_CHAR *IntervalPrint(INTERVAL I, OBJECT x)
 
 OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
   BOOLEAN allow_shrink, BOOLEAN extend_unbreakable, BOOLEAN *hyph_used)
-{ INTERVAL I, BestI;  OBJECT res, gp, tmp, z, y, link, prev;
-  int max_width, etc_width, outdent_margin, f;  BOOLEAN jn;
+{ INTERVAL I, BestI;  OBJECT res, gp, tmp, z, y, link, ylink, prev, next;
+  int max_width, etc_width, outdent_margin, f;  BOOLEAN jn;  unsigned typ;
   static OBJECT hyph_word = nilobj;
   BOOLEAN hyph_allowed;	    /* TRUE when hyphenation of words is permitted  */
   assert( type(x) == ACAT, "FillObject: type(x) != ACAT!" );
@@ -595,7 +718,7 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
   if( multi == nilobj )
   {
     /* set max_width (width of 1st line), etc_width (width of later lines) */
-    max_width = min(fc(*c), bfc(*c));
+    max_width = find_min(fc(*c), bfc(*c));
     if( display_style(save_style(x)) == DISPLAY_OUTDENT ||
         display_style(save_style(x)) == DISPLAY_ORAGGED )
     { outdent_margin = 2 * FontSize(font(save_style(x)), x);
@@ -677,9 +800,12 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
     {
 
       case TOO_LOOSE:
+      case EMPTY_INTERVAL:
       
 	/* too loose, so save best and shift right end */
-	if( IntervalBadness(BestI) <= IntervalBadness(I) )  I = BestI;
+	if( IntervalClass(I) == EMPTY_INTERVAL ||
+	    IntervalBadness(BestI) <= IntervalBadness(I) )
+	      I = BestI;
 	debug1(DOF, DD, "BestI: %s\n", IntervalPrint(I, x));
 	/* NB no break */
 
@@ -693,6 +819,7 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
 
       case LOOSE:
       case TIGHT:
+      case TOO_TIGHT:
       
 	/* reasonable, so check best and shift left end */
 	if( IntervalBadness(I) < IntervalBadness(BestI) )  BestI = I;
@@ -701,13 +828,13 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
 
       case UNBREAKABLE_LEFT:
       case TAB_OVERLAP:
-      case TOO_TIGHT:
       
 	/* too tight, or unbreakable gap at left end, so shift left end */
 	IntervalShiftLeftEnd(I, x, max_width, etc_width);
 	break;
 
 
+      /* ***
       case EMPTY_INTERVAL:
 
 	PrevDefinite(x, I.llink, y);
@@ -717,10 +844,10 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
 	  hyph_allowed = TRUE;
 	  *hyph_used = TRUE;
 	}
-	else CorrectOversize(x, I.llink, y,
-	  (I.cwid!=nilobj) ? bfc(constraint(I.cwid)) : etc_width,
-	  hyph_allowed);
+	else CorrectOversize(x, I.llink,
+	  (I.cwid!=nilobj) ? bfc(constraint(I.cwid)) : etc_width);
 	goto RESTART;
+      *** */
 
 
       default:
@@ -892,12 +1019,51 @@ OBJECT FillObject(OBJECT x, CONSTRAINT *c, OBJECT multi, BOOLEAN can_hyphenate,
       prev = z;
       NextDefiniteWithGap(y, link, z, gp, jn);
     }
-    fwd(y, COLM) = min(MAX_FULL_LENGTH, f + fwd(prev, COLM));
+    fwd(y, COLM) = find_min(MAX_FULL_LENGTH, f + fwd(prev, COLM));
 
     /* make last line DO_ADJUST if it is oversize */
     if( size(y, COLM) > max_width )  display_style(save_style(y)) = DO_ADJUST;
   }
 
+  /* rejoin unused hyphenated gaps so that kerning will work across them */
+  if( *hyph_used && type(res) == VCAT )
+  { for( link = Down(res);  link != res;  link = NextDown(link) )
+    { Child(y, link);
+      if( type(y) == ACAT )
+      { for( ylink = Down(y);  ylink != y;  ylink = NextDown(ylink) )
+        { Child(gp, ylink);
+	  if( type(gp) == GAP_OBJ && width(gap(gp)) == 0 &&
+	      mode(gap(gp)) == ADD_HYPH )
+	  {
+	    /* possible candidate for joining, look into what's on each side */
+	    Child(prev, PrevDown(ylink));
+	    Child(next, NextDown(ylink));
+	    if( is_word(type(prev)) && is_word(type(next)) &&
+	        word_font(prev) == word_font(next) &&
+	        word_colour(prev) == word_colour(next) &&
+	        word_language(prev) == word_language(next) &&
+	        underline(prev) == underline(next) )
+	    { 
+	      debug2(DOF, D, "joining %s with %s", EchoObject(prev),
+		EchoObject(next));
+	      typ = type(prev) == QWORD || type(next) == QWORD ? QWORD : WORD;
+	      tmp = MakeWordTwo(typ, string(prev), string(next), &fpos(prev));
+	      word_font(tmp) = word_font(prev);
+	      word_colour(tmp) = word_colour(prev);
+	      word_language(tmp) = word_language(prev);
+	      word_hyph(tmp) = word_hyph(prev);
+	      FontWordSize(tmp);
+	      underline(tmp) = underline(prev);
+	      MoveLink(ylink, tmp, CHILD);
+	      DisposeChild(Up(prev));
+	      DisposeChild(Up(next));
+	    }
+	  }
+        }
+      }
+    }
+  }
+
   debug0(DOF, DD, "FillObject exiting");
   return res;
 } /* end FillObject */
