@@ -1,6 +1,6 @@
 /*@z15.c:Size Constraints:MinConstraint(), EnlargeToConstraint()@*************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,7 +20,7 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z15.c                                                      */
 /*  MODULE:       Size Constraints                                           */
@@ -34,7 +34,7 @@
 #ifndef M_PI
 #define M_PI       3.1415926535897931160E0
 #endif
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -46,9 +46,9 @@
 /*****************************************************************************/
 
 void MinConstraint(CONSTRAINT *xc, CONSTRAINT *yc)
-{ bc(*xc)  = min(bc(*xc),  bc(*yc));
-  bfc(*xc) = min(bfc(*xc), bfc(*yc));
-  fc(*xc)  = min(fc(*xc),  fc(*yc));
+{ bc(*xc)  = find_min(bc(*xc),  bc(*yc));
+  bfc(*xc) = find_min(bfc(*xc), bfc(*yc));
+  fc(*xc)  = find_min(fc(*xc),  fc(*yc));
 } /* end MinConstraint */
 
 
@@ -62,7 +62,7 @@ void MinConstraint(CONSTRAINT *xc, CONSTRAINT *yc)
 
 void EnlargeToConstraint(FULL_LENGTH *b, FULL_LENGTH *f, CONSTRAINT *c)
 {
-  *f = min(bfc(*c) - *b, fc(*c));
+  *f = find_min(bfc(*c) - *b, fc(*c));
 } /* end EnlargeToConstraint */
 
 
@@ -91,9 +91,9 @@ int ScaleToConstraint(FULL_LENGTH b, FULL_LENGTH f, CONSTRAINT *c)
   debug3(DSC, DD, "ScaleToConstraint(%s, %s, %s)", EchoLength(b),
     EchoLength(f), EchoConstraint(c));
   scale_factor = 1.0;
-  if( b     > 0 )  scale_factor = min(scale_factor, (float) bc(*c)/b       );
-  if( b + f > 0 )  scale_factor = min(scale_factor, (float) bfc(*c)/(b + f));
-  if(     f > 0 )  scale_factor = min(scale_factor, (float) fc(*c)/f       );
+  if( b     > 0 )  scale_factor = find_min(scale_factor, (float) bc(*c)/b       );
+  if( b + f > 0 )  scale_factor = find_min(scale_factor, (float) bfc(*c)/(b + f));
+  if(     f > 0 )  scale_factor = find_min(scale_factor, (float) fc(*c)/f       );
   res = scale_factor * SF;
   debug2(DSC, DD, "ScaleToConstraint returning %.2f (%d)", scale_factor, res);
   return res;
@@ -117,11 +117,11 @@ void InvScaleConstraint(CONSTRAINT *yc, FULL_LENGTH sf, CONSTRAINT *xc)
   debug2(DSC, DD, "InvScaleConstraint(yc, %s, %s)", buff, EchoConstraint(xc));
   assert( sf > 0, "InvScaleConstraint: sf <= 0!" );
   bc(*yc)  = bc(*xc)  == MAX_FULL_LENGTH ? MAX_FULL_LENGTH :
-    min(MAX_FULL_LENGTH, bc(*xc) * SF / sf);
+    find_min(MAX_FULL_LENGTH, bc(*xc) * SF / sf);
   bfc(*yc) = bfc(*xc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH :
-    min(MAX_FULL_LENGTH, bfc(*xc)* SF / sf);
+    find_min(MAX_FULL_LENGTH, bfc(*xc)* SF / sf);
   fc(*yc)  = fc(*xc)  == MAX_FULL_LENGTH ? MAX_FULL_LENGTH :
-    min(MAX_FULL_LENGTH, fc(*xc) * SF / sf);
+    find_min(MAX_FULL_LENGTH, fc(*xc) * SF / sf);
   debug1(DSC, DD, "InvScaleConstraint returning %s", EchoConstraint(yc));
 } /* end InvScaleConstraint */
 
@@ -148,9 +148,9 @@ float angle, CONSTRAINT *yc)
     SetConstraint(*xc, MAX_FULL_LENGTH, MAX_FULL_LENGTH, MAX_FULL_LENGTH);
   else
     SetConstraint(*xc,
-      min(MAX_FULL_LENGTH, (bc(*yc) - u * sn) / cs),
-      min(MAX_FULL_LENGTH, (bfc(*yc) - u * sn - v * sn) / cs),
-      min(MAX_FULL_LENGTH, (fc(*yc) - v * sn) / cs ));
+      find_min(MAX_FULL_LENGTH, (bc(*yc) - u * sn) / cs),
+      find_min(MAX_FULL_LENGTH, (bfc(*yc) - u * sn - v * sn) / cs),
+      find_min(MAX_FULL_LENGTH, (fc(*yc) - v * sn) / cs ));
   debug1(DSC, DD, "SemiRotateConstraint returning %s", EchoConstraint(xc));
 } /* end SemiRotateConstraint */
 
@@ -245,7 +245,11 @@ BOOLEAN InsertScale(OBJECT x, CONSTRAINT *c)
     /* set horizontal size and scale factor */
     bc(constraint(prnt)) = scale_factor;
     back(prnt, COLM) = ( back(x, COLM) * scale_factor ) / SF;
+
+    /* *** slightly too small?
     fwd(prnt,  COLM) = ( fwd(x,  COLM) * scale_factor ) / SF;
+    *** */
+    fwd(prnt,  COLM) = find_min(bfc(*c) - back(prnt, COLM), fc(*c));
 
     /* set vertical size and scale factor */
     fc(constraint(prnt)) = 1 * SF;
@@ -375,10 +379,10 @@ OBJECT y, int dim, OBJECT *why)
 	
 	tbc = bc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bc(yc) - backy;
 	tbfc = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - backy - fwdy;
-	mxy = min(tbc, tbfc);
-	tb  = min(MAX_FULL_LENGTH, be + mxy);
-	tbf = min(MAX_FULL_LENGTH, be + fe + mxy);
-	tf  = min(MAX_FULL_LENGTH, fe + mxy);
+	mxy = find_min(tbc, tbfc);
+	tb  = find_min(MAX_FULL_LENGTH, be + mxy);
+	tbf = find_min(MAX_FULL_LENGTH, be + fe + mxy);
+	tf  = find_min(MAX_FULL_LENGTH, fe + mxy);
 	SetConstraint(*xc, tb, tbf, tf);
 	break;
 
@@ -388,11 +392,11 @@ OBJECT y, int dim, OBJECT *why)
 	tbc = bc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bc(yc) - backy;
 	tbfc = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - backy - fwdy;
 	tfc = fc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : fc(yc) - fwdy;
-	mxy = min(tbc, tbfc);
-	myz = min(tfc, tbfc);
-	tb  = min(MAX_FULL_LENGTH, be + mxy);
-	tbf = min(MAX_FULL_LENGTH, be + fe + tbfc);
-	tf  = min(MAX_FULL_LENGTH, fe + myz);
+	mxy = find_min(tbc, tbfc);
+	myz = find_min(tfc, tbfc);
+	tb  = find_min(MAX_FULL_LENGTH, be + mxy);
+	tbf = find_min(MAX_FULL_LENGTH, be + fe + tbfc);
+	tf  = find_min(MAX_FULL_LENGTH, fe + myz);
 	SetConstraint(*xc, tb, tbf, tf);
 	break;
 	
@@ -401,10 +405,10 @@ OBJECT y, int dim, OBJECT *why)
 
 	tfc = fc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : fc(yc) - fwdy;
 	tbfc = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - backy - fwdy;
-	mxy = min(tfc, tbfc);
-	tb  = min(MAX_FULL_LENGTH, be + mxy);
-	tbf = min(MAX_FULL_LENGTH, be + fe + mxy);
-	tf  = min(MAX_FULL_LENGTH, fe + mxy);
+	mxy = find_min(tfc, tbfc);
+	tb  = find_min(MAX_FULL_LENGTH, be + mxy);
+	tbf = find_min(MAX_FULL_LENGTH, be + fe + mxy);
+	tf  = find_min(MAX_FULL_LENGTH, fe + mxy);
 	SetConstraint(*xc, tb, tbf, tf);
 	break;
 	
@@ -524,7 +528,7 @@ void Constrained(OBJECT x, CONSTRAINT *xc, int dim, OBJECT *why)
       { Constrained(y, &yc, dim, why);
 	tf = FindShift(y, x, dim);
 	SetConstraint(*xc,
-	  min(bc(yc), bfc(yc)) - tf, bfc(yc), min(fc(yc), bfc(yc)) + tf);
+	  find_min(bc(yc), bfc(yc)) - tf, bfc(yc), find_min(fc(yc), bfc(yc)) + tf);
       }
       else Constrained(y, xc, dim, why);
       break;
@@ -548,9 +552,9 @@ void Constrained(OBJECT x, CONSTRAINT *xc, int dim, OBJECT *why)
       assert( (type(y)==COL_THR) == (dim==COLM), "Constrained: COL_THR!" );
       Constrained(y, &yc, dim, why);
       tb = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - fwd(y, dim);
-      tb = min(bc(yc), tb);
+      tb = find_min(bc(yc), tb);
       tf = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - back(y, dim);
-      tf = min(fc(yc), tf);
+      tf = find_min(fc(yc), tf);
       SetConstraint(*xc, tb, bfc(yc), tf);
       break;
 
@@ -583,9 +587,9 @@ void Constrained(OBJECT x, CONSTRAINT *xc, int dim, OBJECT *why)
 	{
 	  /* if whole object is joined, do this */
           tb = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - fwd(y, dim);
-          tb = min(bc(yc), tb);
+          tb = find_min(bc(yc), tb);
           tf = bfc(yc) == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : bfc(yc) - back(y, dim);
-          tf = min(fc(yc), tf);
+          tf = find_min(fc(yc), tf);
           SetConstraint(*xc, tb, bfc(yc), tf);
 	}
 	else
@@ -595,11 +599,12 @@ void Constrained(OBJECT x, CONSTRAINT *xc, int dim, OBJECT *why)
 	  for(link = NextDown(lp); link != rp;  link = NextDown(link) )
 	  { Child(z, link);
 	    if( type(z) == GAP_OBJ || is_index(type(z)) )  continue;
-	    xback = max(xback, back(z, dim));  xfwd = max(xfwd, fwd(z, dim));
+	    xback = find_max(xback, back(z, dim));
+	    xfwd = find_max(xfwd, fwd(z, dim));
 	  }
 	  debug2(DSC, DD, "  lp != rp; xback,xfwd = %s,%s",
 			EchoLength(xback), EchoLength(xfwd));
-	  tbf = min(bfc(yc), fc(yc));
+	  tbf = find_min(bfc(yc), fc(yc));
 	  tbc = tbf == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : tbf - xfwd;
 	  tfc = tbf == MAX_FULL_LENGTH ? MAX_FULL_LENGTH : tbf - xback;
 	  SetConstraint(*xc, tbc, tbf, tfc);
@@ -635,6 +640,7 @@ FULL_CHAR *EchoConstraint(CONSTRAINT *c)
   switch( BackEnd )
   {
     case POSTSCRIPT:
+    case PDF:
 
       if( bc(*c)==MAX_FULL_LENGTH )  sprintf(&str[i][strlen(str[i])], "INF, ");
       else sprintf(&str[i][strlen(str[i])], "%.3fc, ", (float) bc(*c)/CM);
