@@ -1,6 +1,6 @@
 /*@z16.c:Size Adjustment:SetNeighbours(), CatAdjustSize()@********************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z16.c                                                      */
 /*  MODULE:       Size Adjustment                                            */
 /*  EXTERNS:      FindShift(), SetNeighbours(), AdjustSize()                 */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -315,8 +315,8 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 	  if( lp == y && rp == y && !seen_nojoin(y) )
 	  {	
 	    /* if whole object is joined, do this */
-	    b = max(b, back(y, dim));
-	    f = max(f, fwd(y, dim));
+	    b = find_max(b, back(y, dim));
+	    f = find_max(f, fwd(y, dim));
 	  }
 	  else
 	  {
@@ -329,10 +329,10 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 		  "  z %s (size %s,%s) = ", Image(type(z)),
 		  EchoLength(back(z, dim)), EchoLength(fwd(z, dim)));
 	      ifdebugcond(DSA, DD,  dim == COLM && fwd(z, dim) > 20*CM, DebugObject(z));
-	      tb = max(tb, back(z, dim));
-	      tf = max(tf, fwd(z, dim));
+	      tb = find_max(tb, back(z, dim));
+	      tf = find_max(tf, fwd(z, dim));
 	    }
-	    b = 0;  f = max(tb + tf, fwd(y, dim));
+	    b = 0;  f = find_max(tb + tf, fwd(y, dim));
 	  }
 	  if( back(y, dim) == b && fwd(y, dim) == f )
 	  {
@@ -459,8 +459,8 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 	back(x, dim) = b;  fwd(x, dim) = f;
 	if( (type(y) == HSHIFT) == (dim == COLM) )
 	{ tf = FindShift(y, x, dim);
-	  b = min(MAX_FULL_LENGTH, max(0, b + tf));
-	  f = min(MAX_FULL_LENGTH, max(0, f - tf));
+	  b = find_min(MAX_FULL_LENGTH, find_max(0, b + tf));
+	  f = find_min(MAX_FULL_LENGTH, find_max(0, f - tf));
 	}
 	break;
 
@@ -470,8 +470,8 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 
 	assert( (type(y)==COL_THR) == (dim==COLM), "AdjustSize: COL_THR!" );
 	back(x, dim) = b;  fwd(x, dim) = f;
-	b = max(b, back(y, dim));
-	f = max(f, fwd(y, dim));
+	b = find_max(b, back(y, dim));
+	f = find_max(f, fwd(y, dim));
 	break;
 
 
@@ -497,8 +497,8 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 	  if( lp == y && rp == y )
 	  {
 	    /* if whole object is joined, do this */
-	    b = max(b, back(y, dim));
-	    f = max(f, fwd(y, dim));
+	    b = find_max(b, back(y, dim));
+	    f = find_max(f, fwd(y, dim));
 	  }
 	  else
 	  { /* if // or || is present, do this */
@@ -506,10 +506,10 @@ void AdjustSize(OBJECT x, FULL_LENGTH b, FULL_LENGTH f, int dim)
 	    for( link = NextDown(lp); link != rp;  link = NextDown(link) )
 	    { Child(z, link);
 	      if( type(z) == GAP_OBJ || is_index(type(z)) )  continue;
-	      tb = max(tb, back(z, dim));
-	      tf = max(tf, fwd(z, dim));
+	      tb = find_max(tb, back(z, dim));
+	      tf = find_max(tf, fwd(z, dim));
 	    }
-	    b = 0;  f = max(tb + tf, fwd(y, dim));
+	    b = 0;  f = find_max(tb + tf, fwd(y, dim));
 	  }
 	}
 	break;
