@@ -1,6 +1,6 @@
 /*@z22.c:Galley Service:Interpose()@******************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,7 +20,7 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z22.c                                                      */
 /*  MODULE:       Galley Service                                             */
@@ -29,7 +29,7 @@
 /*                SetTarget(), CheckComponentOrder()                         */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -650,8 +650,8 @@ void Promote(OBJECT hd, OBJECT stop_link, OBJECT dest_index)
       Child(tmp2, DownDim(y, COLM));
       assert( type(tmp2) == COL_THR, "Promote: tmp2 not COL_THR!" );
       if( tmp1 != tmp2 )
-      { FULL_LENGTH b = max(back(tmp1, COLM), back(tmp2, COLM));
-	FULL_LENGTH f = max(fwd(tmp1, COLM),  fwd(tmp2, COLM));
+      { FULL_LENGTH b = find_max(back(tmp1, COLM), back(tmp2, COLM));
+	FULL_LENGTH f = find_max(fwd(tmp1, COLM),  fwd(tmp2, COLM));
 	debug0(DSA, D, "calling AdjustSize(tmp1) from Promote (node merging)");
 	AdjustSize(tmp1, b, f, COLM);
 	debug0(DSA, D, "calling AdjustSize(tmp2) from Promote (node merging)");
@@ -855,8 +855,8 @@ OBJECT relocate_link, OBJECT sym)
 void SetTarget(OBJECT hd)
 { OBJECT x, y, link, cr, lpar, rpar, env;
   BOOLEAN copied;
-  debug1(DGS, D, "SetTarget(%s)", SymName(actual(x)));
-  assert( type(hd) == HEAD, "SetTarget: type(x) != HEAD!" );
+  debug1(DGS, D, "SetTarget(%s)", SymName(actual(hd)));
+  assert( type(hd) == HEAD, "SetTarget: type(hd) != HEAD!" );
   Child(x, Down(hd));
   assert( type(x) == CLOSURE, "SetTarget: type(x) != CLOSURE!" );
   assert( has_target(actual(x)), "SetTarget: x has no target!" );
