@@ -1,6 +1,6 @@
 /*@z25.c:Object Echo:aprint(), cprint(), printnum()@**************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z25.c                                                      */
 /*  MODULE:       Object Echo                                                */
 /*  EXTERNS:      EchoObject(), DebugObject()                                */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 #if DEBUG_ON
 
 static	int	limit;			/* column where newline is needed    */
@@ -680,7 +680,7 @@ static void echo(OBJECT x, unsigned outer_prec)
 	/* print left parameter */
 	if( Down(x) != LastDown(x) )
 	{ Child(y, Down(x));
-	  echo(y, max(outer_prec, DEFAULT_PREC));
+	  echo(y, find_max(outer_prec, DEFAULT_PREC));
 	  aprint(" ");
 	}
 
@@ -690,12 +690,14 @@ static void echo(OBJECT x, unsigned outer_prec)
 	assert( LastDown(x) != x, "echo: right parameter of predefined!" );
 	aprint(" ");
 	Child(y, LastDown(x));
-	echo(y, type(x)==OPEN ? FORCE_PREC : max(outer_prec,DEFAULT_PREC));
+	echo(y, type(x)==OPEN ? FORCE_PREC : find_max(outer_prec,DEFAULT_PREC));
 	if( braces_needed )  aprint(" "), cprint(KW_RBR);
 	break;
 
 
     case CURR_LANG:
+    case CURR_FAMILY:
+    case CURR_FACE:
     case BACKEND:
     case PAGE_LABEL:
 
