@@ -1,6 +1,6 @@
 /*@z44.c:Vertical Hyphenation:VerticalHyphenate()@****************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,14 +20,14 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z44.c                                                      */
 /*  MODULE:       Vertical Hyphenation                                       */
 /*  EXTERNS:      VerticalHyphenate(), ConvertGalleyList()                   */
 /*                                                                           */
 /*****************************************************************************/
-#include "externs"
+#include "externs.h"
 
 
 /*****************************************************************************/
@@ -310,7 +310,7 @@ BOOLEAN VerticalHyphenate(OBJECT y)
 
     /* Now sh is one of the HCAT components */
     if( type(sh) != VCAT )
-    { rump_fwd = max(rump_fwd, fwd(sh, ROWM));
+    { rump_fwd = find_max(rump_fwd, fwd(sh, ROWM));
     }
     else if( large_comp != nilobj )
     { debug0(DVH, D, "] VerticalHyphenate returning FALSE (two VCATs)");
@@ -341,7 +341,7 @@ BOOLEAN VerticalHyphenate(OBJECT y)
   }
 
   /* make sure that first gap does not change when rearranging */
-  rump_fwd = max(rump_fwd, fwd(prev, ROWM));
+  rump_fwd = find_max(rump_fwd, fwd(prev, ROWM));
   if( MinGap(rump_fwd, back(nxt, ROWM), fwd(nxt, ROWM), &gap(g)) !=
       MinGap(fwd(prev, ROWM), back(nxt, ROWM), fwd(nxt, ROWM), &gap(g)) )
   { debug0(DVH, D, "] VerticalHyphenate returning FALSE (first gap changes)");
