@@ -1,6 +1,6 @@
 /*@z45.c:External Sort:SortFile()@********************************************/
 /*                                                                           */
-/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.10)                       */
+/*  THE LOUT DOCUMENT FORMATTING SYSTEM (VERSION 3.12)                       */
 /*  COPYRIGHT (C) 1991, 1996 Jeffrey H. Kingston                             */
 /*                                                                           */
 /*  Jeffrey H. Kingston (jeff@cs.usyd.edu.au)                                */
@@ -10,7 +10,7 @@
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
 /*  it under the terms of the GNU General Public License as published by     */
-/*  the Free Software Foundation; either version 1, or (at your option)      */
+/*  the Free Software Foundation; either Version 2, or (at your option)      */
 /*  any later version.                                                       */
 /*                                                                           */
 /*  This program is distributed in the hope that it will be useful,          */
@@ -20,7 +20,7 @@
 /*                                                                           */
 /*  You should have received a copy of the GNU General Public License        */
 /*  along with this program; if not, write to the Free Software              */
-/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA   */
 /*                                                                           */
 /*  FILE:         z45.c                                                      */
 /*  MODULE:       External Sort                                              */
@@ -52,8 +52,8 @@
    The author may be reached (Email) at the address mike@gnu.ai.mit.edu,
    or (US mail) as Mike Haertel c/o Free Software Foundation. */
 
-#include <sys/types.h>
-#include "externs"
+/* apparently not needed #include <sys/types.h> */
+#include "externs.h"
 
 #ifndef UCHAR_MAX
 #define UCHAR_MAX 255
@@ -61,13 +61,12 @@
 
 /* from system.h */
 
-#include <string.h>
+#include <string.h>   /* uwe: it also gives us strcoll() */
 /* already included in externs #include <stdlib.h> */
 #include <ctype.h>
 
 /* end system.h */
 
-#define min(a, b) ((a) < (b) ? (a) : (b))
 #define UCHAR_LIM (UCHAR_MAX + 1)
 #define UCHAR(c) ((unsigned char) (c))
 
@@ -145,7 +144,7 @@ struct buffer
 
 /* Allocate N bytes of memory dynamically, with error checking.  */
 
-char *
+static char *
 xmalloc (n)
      unsigned n;
 {
@@ -165,7 +164,7 @@ xmalloc (n)
    If P is NULL, run xmalloc.
    If N is 0, run free and return NULL.  */
 
-char *
+static char *
 xrealloc (p, n)
      char *p;
      unsigned n;
@@ -355,6 +354,23 @@ findlines (buf, lines)
 /* Compare two lines A and B, returning negative, zero, or positive
    depending on whether A compares less than, equal to, or greater than B. */
 
+#if COLLATE
+static int
+compare (a, b)
+     register struct line *a, *b;
+{
+  int tmpa, tmpb, mini;
+
+      tmpa = a->length, tmpb = b->length;
+      mini = find_min(tmpa, tmpb);
+      if (mini == 0)
+	return tmpa - tmpb;
+      else
+	return strcoll (a->text, b->text);
+}
+
+#else /* !COLLATE -- good old ASCIIbetical order */
+
 static int
 compare (a, b)
      register struct line *a, *b;
@@ -362,7 +378,7 @@ compare (a, b)
   int diff, tmpa, tmpb, mini;
 
       tmpa = a->length, tmpb = b->length;
-      mini = min (tmpa, tmpb);
+      mini = find_min(tmpa, tmpb);
       if (mini == 0)
 	diff = tmpa - tmpb;
       else
@@ -380,6 +396,7 @@ compare (a, b)
 
   return diff;
 }
+#endif /* !COLLATE */
 
 /* Sort the array LINES with NLINES members, using TEMP for temporary space. */
 
